#include <avr/pgmspace.h>       // definitions or keeping constants in program memory
#include "main.h"

// table of POWER codes

#define freq_to_timerval(x) ((F_CPU / x - 1 )/ 2)

const uint16_t philipsTimes[] PROGMEM = {
273,92,
46,92,
46,46,
138,135,
92,46,
46,8547,
45,46,
46,0,
};

const struct IrCode code_philips PROGMEM = {
    freq_to_timerval(34760),
    philipsTimes,
    {
    0x01,
    0x22,
    0x32,
    0x22,
    0x22,
    0x22,
    0x22,
    0x22,
    0x41,
    0x25,
    0x01,
    0x22,
    0x32,
    0x26,
    0x22,
    0x22,
    0x22,
    0x22,
    0x41,
    0x27,
    0x0,
}
};

const uint16_t grundigTimes[] PROGMEM = {
54,270,
54,53,
54,2107,
54,268,
54,109,
105,109,
54,11969,
54,0,
};

const struct IrCode code_grundig PROGMEM = {
    freq_to_timerval(29510),
    grundigTimes,
    {
    0x01,
    0x11,
    0x11,
    0x11,
    0x11,
    0x23,
    0x45,
    0x11,
    0x11,
    0x11,
    0x63,
    0x45,
    0x11,
    0x11,
    0x11,
    0x70,
}
};

const uint16_t brandtTimes[] PROGMEM = {
49,209,
49,208,
49,466,
49,3581,
49,0,
};

const struct IrCode code_brandt PROGMEM = {
    freq_to_timerval(32450),
    brandtTimes,
    {
    0x01,
    0x22,
    0x11,
    0x12,
    0x22,
    0x12,
    0x31,
    0x12,
    0x21,
    0x11,
    0x22,
    0x21,
    0x24,
    0x0,
}
};

const uint16_t sonyTimes[] PROGMEM = {
245,60,
123,60,
61,60,
61,2759,
61,0,
};

const struct IrCode code_sony PROGMEM = {
    freq_to_timerval(37470),
    sonyTimes,
    {
    0x01,
    0x21,
    0x21,
    0x22,
    0x12,
    0x22,
    0x30,
    0x12,
    0x12,
    0x12,
    0x21,
    0x22,
    0x24,
    0x0,
}
};

const uint16_t panasonicTimes[] PROGMEM = {
358,179,
47,44,
47,133,
47,7661,
358,180,
47,0,
};

const struct IrCode code_panasonic PROGMEM = {
    freq_to_timerval(36090),
    panasonicTimes,
    {
    0x01,
    0x21,
    0x11,
    0x11,
    0x11,
    0x11,
    0x11,
    0x21,
    0x11,
    0x11,
    0x11,
    0x11,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x12,
    0x22,
    0x21,
    0x12,
    0x12,
    0x22,
    0x21,
    0x23,
    0x41,
    0x21,
    0x11,
    0x11,
    0x11,
    0x11,
    0x11,
    0x21,
    0x11,
    0x11,
    0x11,
    0x11,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x12,
    0x22,
    0x21,
    0x12,
    0x12,
    0x22,
    0x21,
    0x25,
    0x0,
}
};

const uint16_t sharpTimes[] PROGMEM = {
27,194,
27,81,
27,4928,
27,4311,
27,0,
};

const struct IrCode code_sharp PROGMEM = {
    freq_to_timerval(37470),
    sharpTimes,
    {
    0x01,
    0x11,
    0x11,
    0x00,
    0x10,
    0x11,
    0x10,
    0x12,
    0x01,
    0x11,
    0x10,
    0x11,
    0x01,
    0x00,
    0x01,
    0x03,
    0x01,
    0x11,
    0x11,
    0x00,
    0x10,
    0x11,
    0x10,
    0x12,
    0x01,
    0x11,
    0x10,
    0x11,
    0x01,
    0x00,
    0x01,
    0x04,
    0x0,
}
};

const uint16_t samsungTimes[] PROGMEM = {
468,480,
55,175,
55,64,
55,4592,
55,0,
};

const struct IrCode code_samsung PROGMEM = {
    freq_to_timerval(37043),
    samsungTimes,
    {
    0x01,
    0x11,
    0x22,
    0x22,
    0x21,
    0x11,
    0x22,
    0x22,
    0x22,
    0x12,
    0x22,
    0x22,
    0x21,
    0x21,
    0x11,
    0x11,
    0x13,
    0x01,
    0x11,
    0x22,
    0x22,
    0x21,
    0x11,
    0x22,
    0x22,
    0x22,
    0x12,
    0x22,
    0x22,
    0x21,
    0x21,
    0x11,
    0x11,
    0x14,
    0x0,
}
};

const uint16_t jvcTimes[] PROGMEM = {
862,431,
53,161,
53,53,
53,2368,
53,2367,
53,0,
};

const struct IrCode code_jvc PROGMEM = {
    freq_to_timerval(37470),
    jvcTimes,
    {
    0x01,
    0x12,
    0x22,
    0x22,
    0x21,
    0x11,
    0x21,
    0x22,
    0x23,
    0x11,
    0x22,
    0x22,
    0x22,
    0x11,
    0x12,
    0x12,
    0x22,
    0x41,
    0x12,
    0x22,
    0x22,
    0x21,
    0x11,
    0x21,
    0x22,
    0x25,
    0x0,
}
};

const uint16_t hitachiTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_hitachi PROGMEM = {
    freq_to_timerval(37470),
    hitachiTimes,
    {
    0x01,
    0x11,
    0x12,
    0x12,
    0x12,
    0x22,
    0x21,
    0x21,
    0x22,
    0x22,
    0x12,
    0x11,
    0x11,
    0x11,
    0x21,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t nonamesTimes[] PROGMEM = {
92,92,
184,92,
92,184,
92,9217,
91,92,
92,0,
};

const struct IrCode code_nonames PROGMEM = {
    freq_to_timerval(34800),
    nonamesTimes,
    {
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x13,
    0x41,
    0x00,
    0x00,
    0x00,
    0x20,
    0x15,
    0x0,
}
};

const uint16_t toshiba2Times[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_toshiba2 PROGMEM = {
    freq_to_timerval(37470),
    toshiba2Times,
    {
    0x01,
    0x11,
    0x11,
    0x12,
    0x12,
    0x22,
    0x22,
    0x21,
    0x21,
    0x21,
    0x12,
    0x11,
    0x12,
    0x12,
    0x21,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t goodmansTimes[] PROGMEM = {
924,462,
56,174,
56,56,
56,4055,
926,230,
56,9857,
56,0,
};

const struct IrCode code_goodmans PROGMEM = {
    freq_to_timerval(37470),
    goodmansTimes,
    {
    0x01,
    0x22,
    0x21,
    0x12,
    0x21,
    0x22,
    0x12,
    0x21,
    0x21,
    0x12,
    0x22,
    0x11,
    0x22,
    0x21,
    0x11,
    0x22,
    0x13,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t aiwaTimes[] PROGMEM = {
920,430,
56,175,
56,59,
56,2362,
921,460,
56,0,
};

const struct IrCode code_aiwa PROGMEM = {
    freq_to_timerval(37430),
    aiwaTimes,
    {
    0x01,
    0x12,
    0x11,
    0x11,
    0x22,
    0x22,
    0x22,
    0x22,
    0x12,
    0x22,
    0x21,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x21,
    0x11,
    0x11,
    0x11,
    0x13,
    0x41,
    0x12,
    0x11,
    0x11,
    0x22,
    0x22,
    0x22,
    0x22,
    0x12,
    0x22,
    0x21,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x21,
    0x11,
    0x11,
    0x11,
    0x15,
    0x0,
}
};

const uint16_t daewooTimes[] PROGMEM = {
822,409,
51,52,
51,163,
51,409,
51,2397,
51,0,
};

const struct IrCode code_daewoo PROGMEM = {
    freq_to_timerval(37470),
    daewooTimes,
    {
    0x01,
    0x12,
    0x12,
    0x11,
    0x13,
    0x21,
    0x21,
    0x21,
    0x11,
    0x40,
    0x11,
    0x21,
    0x21,
    0x11,
    0x32,
    0x12,
    0x12,
    0x11,
    0x15,
    0x0,
}
};

const uint16_t pioneerTimes[] PROGMEM = {
876,435,
56,54,
56,159,
56,2610,
877,434,
56,0,
};

const struct IrCode code_pioneer PROGMEM = {
    freq_to_timerval(37470),
    pioneerTimes,
    {
    0x01,
    0x21,
    0x21,
    0x21,
    0x22,
    0x12,
    0x12,
    0x12,
    0x11,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x22,
    0x23,
    0x41,
    0x21,
    0x21,
    0x21,
    0x22,
    0x12,
    0x12,
    0x12,
    0x11,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x22,
    0x23,
    0x41,
    0x21,
    0x21,
    0x21,
    0x22,
    0x12,
    0x12,
    0x12,
    0x11,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x22,
    0x25,
    0x0,
}
};

const uint16_t mitsubishiTimes[] PROGMEM = {
31,216,
31,218,
31,92,
31,2844,
31,0,
};

const struct IrCode code_mitsubishi PROGMEM = {
    freq_to_timerval(32450),
    mitsubishiTimes,
    {
    0x01,
    0x12,
    0x22,
    0x12,
    0x21,
    0x22,
    0x22,
    0x22,
    0x31,
    0x11,
    0x22,
    0x21,
    0x22,
    0x12,
    0x22,
    0x22,
    0x24,
    0x0,
}
};

const uint16_t sanyoTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_sanyo PROGMEM = {
    freq_to_timerval(37470),
    sanyoTimes,
    {
    0x01,
    0x11,
    0x22,
    0x21,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t acuraTimes[] PROGMEM = {
868,427,
53,53,
53,161,
53,428,
53,2507,
868,428,
52,0,
};

const struct IrCode code_acura PROGMEM = {
    freq_to_timerval(37470),
    acuraTimes,
    {
    0x01,
    0x21,
    0x11,
    0x11,
    0x13,
    0x12,
    0x22,
    0x11,
    0x11,
    0x45,
    0x12,
    0x11,
    0x11,
    0x11,
    0x31,
    0x22,
    0x21,
    0x11,
    0x16,
    0x0,
}
};

const uint16_t radiolaTimes[] PROGMEM = {
51,307,
51,1026,
51,309,
51,667,
51,3079,
51,0,
};

const struct IrCode code_radiola PROGMEM = {
    freq_to_timerval(34800),
    radiolaTimes,
    {
    0x01,
    0x21,
    0x21,
    0x22,
    0x22,
    0x22,
    0x22,
    0x23,
    0x42,
    0x12,
    0x12,
    0x12,
    0x22,
    0x22,
    0x22,
    0x22,
    0x35,
    0x0,
}
};

const uint16_t magnavoxTimes[] PROGMEM = {
924,462,
56,174,
56,56,
56,4055,
926,230,
56,9857,
54,0,
};

const struct IrCode code_magnavox PROGMEM = {
    freq_to_timerval(37470),
    magnavoxTimes,
    {
    0x01,
    0x12,
    0x22,
    0x22,
    0x12,
    0x12,
    0x11,
    0x11,
    0x22,
    0x22,
    0x12,
    0x22,
    0x21,
    0x11,
    0x21,
    0x11,
    0x13,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t hitashi3Times[] PROGMEM = {
924,464,
58,173,
58,57,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_hitashi3 PROGMEM = {
    freq_to_timerval(37470),
    hitashi3Times,
    {
    0x01,
    0x12,
    0x21,
    0x21,
    0x22,
    0x21,
    0x12,
    0x12,
    0x11,
    0x11,
    0x21,
    0x22,
    0x22,
    0x22,
    0x12,
    0x11,
    0x13,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t necTimes[] PROGMEM = {
918,460,
56,60,
56,178,
56,4582,
921,229,
56,9707,
55,0,
};

const struct IrCode code_nec PROGMEM = {
    freq_to_timerval(37470),
    necTimes,
    {
    0x01,
    0x11,
    0x22,
    0x11,
    0x11,
    0x11,
    0x22,
    0x11,
    0x11,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x21,
    0x13,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t granadaTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_granada PROGMEM = {
    freq_to_timerval(37430),
    granadaTimes,
    {
    0x01,
    0x11,
    0x22,
    0x21,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x12,
    0x11,
    0x12,
    0x22,
    0x21,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t asaTimes[] PROGMEM = {
53,255,
53,102,
105,51,
53,51,
53,2439,
53,256,
105,102,
53,12337,
53,0,
};

const struct IrCode code_asa PROGMEM = {
    freq_to_timerval(30460),
    asaTimes,
    {
    0x01,
    0x23,
    0x33,
    0x45,
    0x16,
    0x33,
    0x37,
    0x51,
    0x63,
    0x33,
    0x80,
}
};

const uint16_t samsung2Times[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_samsung2 PROGMEM = {
    freq_to_timerval(37470),
    samsung2Times,
    {
    0x01,
    0x21,
    0x21,
    0x21,
    0x22,
    0x12,
    0x12,
    0x12,
    0x12,
    0x12,
    0x11,
    0x12,
    0x21,
    0x21,
    0x22,
    0x21,
    0x13,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t dumontTimes[] PROGMEM = {
54,272,
54,55,
54,2108,
54,270,
54,111,
105,56,
54,12444,
54,0,
};

const struct IrCode code_dumont PROGMEM = {
    freq_to_timerval(29510),
    dumontTimes,
    {
    0x01,
    0x11,
    0x11,
    0x11,
    0x11,
    0x23,
    0x41,
    0x54,
    0x11,
    0x11,
    0x63,
    0x41,
    0x54,
    0x11,
    0x11,
    0x70,
}
};

const uint16_t novatronicTimes[] PROGMEM = {
54,255,
54,99,
107,48,
54,49,
54,1482,
54,256,
107,99,
54,11310,
54,0,
};

const struct IrCode code_novatronic PROGMEM = {
    freq_to_timerval(33600),
    novatronicTimes,
    {
    0x01,
    0x23,
    0x33,
    0x33,
    0x33,
    0x33,
    0x33,
    0x34,
    0x51,
    0x32,
    0x13,
    0x33,
    0x63,
    0x33,
    0x33,
    0x75,
    0x13,
    0x21,
    0x33,
    0x36,
    0x33,
    0x33,
    0x38,
    0x0,
}
};

const uint16_t lgTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_lg PROGMEM = {
    freq_to_timerval(37470),
    lgTimes,
    {
    0x01,
    0x12,
    0x11,
    0x11,
    0x12,
    0x21,
    0x22,
    0x22,
    0x21,
    0x11,
    0x21,
    0x11,
    0x12,
    0x22,
    0x12,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t jvc2Times[] PROGMEM = {
862,431,
56,163,
56,53,
56,1741,
56,0,
};

const struct IrCode code_jvc2 PROGMEM = {
    freq_to_timerval(37430),
    jvc2Times,
    {
    0x01,
    0x11,
    0x11,
    0x22,
    0x21,
    0x11,
    0x21,
    0x21,
    0x13,
    0x11,
    0x11,
    0x12,
    0x22,
    0x11,
    0x12,
    0x12,
    0x11,
    0x31,
    0x11,
    0x11,
    0x22,
    0x21,
    0x11,
    0x21,
    0x21,
    0x14,
    0x0,
}
};

const uint16_t thomsonTimes[] PROGMEM = {
52,209,
52,466,
52,3788,
52,0,
};

const struct IrCode code_thomson PROGMEM = {
    freq_to_timerval(32520),
    thomsonTimes,
    {
    0x00,
    0x11,
    0x00,
    0x01,
    0x11,
    0x00,
    0x20,
    0x01,
    0x10,
    0x00,
    0x11,
    0x10,
    0x03,
    0x0,
}
};

const uint16_t siemensTimes[] PROGMEM = {
53,152,
53,354,
53,151,
53,3014,
53,0,
};

const struct IrCode code_siemens PROGMEM = {
    freq_to_timerval(37430),
    siemensTimes,
    {
    0x01,
    0x11,
    0x22,
    0x32,
    0x11,
    0x12,
    0x24,
    0x0,
}
};

const uint16_t nec2Times[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_nec2 PROGMEM = {
    freq_to_timerval(37470),
    nec2Times,
    {
    0x01,
    0x11,
    0x22,
    0x11,
    0x12,
    0x22,
    0x11,
    0x22,
    0x21,
    0x11,
    0x21,
    0x11,
    0x12,
    0x22,
    0x12,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t adventTimes[] PROGMEM = {
92,92,
184,92,
92,184,
92,9217,
92,0,
};

const struct IrCode code_advent PROGMEM = {
    freq_to_timerval(34800),
    adventTimes,
    {
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x13,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x14,
    0x0,
}
};

const uint16_t triumphTimes[] PROGMEM = {
924,464,
58,173,
58,57,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_triumph PROGMEM = {
    freq_to_timerval(37470),
    triumphTimes,
    {
    0x01,
    0x22,
    0x21,
    0x11,
    0x22,
    0x11,
    0x12,
    0x22,
    0x12,
    0x22,
    0x12,
    0x22,
    0x21,
    0x11,
    0x21,
    0x11,
    0x13,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t fujitsuTimes[] PROGMEM = {
15,690,
15,691,
15,456,
15,4705,
15,0,
};

const struct IrCode code_fujitsu PROGMEM = {
    freq_to_timerval(38970),
    fujitsuTimes,
    {
    0x01,
    0x11,
    0x12,
    0x21,
    0x12,
    0x23,
    0x11,
    0x11,
    0x12,
    0x21,
    0x12,
    0x24,
    0x0,
}
};

const uint16_t blueskyTimes[] PROGMEM = {
358,358,
89,90,
89,269,
89,3492,
359,358,
89,0,
};

const struct IrCode code_bluesky PROGMEM = {
    freq_to_timerval(34800),
    blueskyTimes,
    {
    0x01,
    0x22,
    0x12,
    0x11,
    0x21,
    0x21,
    0x12,
    0x11,
    0x21,
    0x22,
    0x12,
    0x12,
    0x23,
    0x41,
    0x22,
    0x12,
    0x11,
    0x21,
    0x21,
    0x12,
    0x11,
    0x21,
    0x22,
    0x12,
    0x12,
    0x25,
    0x0,
}
};

const uint16_t phonolaTimes[] PROGMEM = {
49,306,
52,1022,
52,304,
52,663,
52,3137,
52,0,
};

const struct IrCode code_phonola PROGMEM = {
    freq_to_timerval(32480),
    phonolaTimes,
    {
    0x01,
    0x21,
    0x21,
    0x23,
    0x33,
    0x32,
    0x24,
    0x21,
    0x21,
    0x21,
    0x23,
    0x33,
    0x32,
    0x25,
    0x0,
}
};

const uint16_t firstlineTimes[] PROGMEM = {
924,462,
56,56,
56,174,
56,4055,
926,230,
56,9857,
56,0,
};

const struct IrCode code_firstline PROGMEM = {
    freq_to_timerval(37470),
    firstlineTimes,
    {
    0x01,
    0x11,
    0x11,
    0x11,
    0x22,
    0x22,
    0x21,
    0x22,
    0x11,
    0x21,
    0x21,
    0x11,
    0x12,
    0x12,
    0x12,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t weirdTimes[] PROGMEM = {
1067,4329,
1069,0,
};

const struct IrCode code_weird PROGMEM = {
    freq_to_timerval(40580),
    weirdTimes,
    {
    0x01,
    0x0,
}
};

const uint16_t toshiba4Times[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_toshiba4 PROGMEM = {
    freq_to_timerval(37430),
    toshiba4Times,
    {
    0x01,
    0x11,
    0x21,
    0x12,
    0x12,
    0x22,
    0x12,
    0x21,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t acerTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9880,
58,0,
};

const struct IrCode code_acer PROGMEM = {
    freq_to_timerval(37470),
    acerTimes,
    {
    0x01,
    0x11,
    0x11,
    0x22,
    0x12,
    0x22,
    0x22,
    0x11,
    0x22,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t viewsonicTimes[] PROGMEM = {
924,461,
56,56,
56,174,
56,4055,
926,230,
56,9855,
56,0,
};

const struct IrCode code_viewsonic PROGMEM = {
    freq_to_timerval(37470),
    viewsonicTimes,
    {
    0x01,
    0x11,
    0x12,
    0x12,
    0x12,
    0x12,
    0x21,
    0x21,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x23,
    0x45,
    0x46,
    0x0,
}
};

const uint16_t tvbgone4Times[] PROGMEM = {
	27, 77,
	25, 80,
	25, 187,
	26, 4187,
	25, 4786,
	25, 0,
};

const struct IrCode code_tvbgone4 PROGMEM = {
	freq_to_timerval(38885),
	tvbgone4Times,
	{
		0x20,
		0x01,
		0x00,
		0x22,
		0x02,
		0x01,
		0x02,
		0x04,
		0x20,
		0x01,
		0x02,
		0x01,
		0x21,
		0x22,
		0x20,
		0x23,
		0x20,
		0x01,
		0x00,
		0x22,
		0x02,
		0x01,
		0x02,
		0x04,
		0x20,
		0x01,
		0x02,
		0x01,
		0x21,
		0x22,
		0x20,
		0x23,
		0x20,
		0x01,
		0x00,
		0x22,
		0x02,
		0x01,
		0x02,
		0x04,
		0x20,
		0x01,
		0x02,
		0x01,
		0x21,
		0x22,
		0x20,
		0x23,
		0x20,
		0x01,
		0x00,
		0x22,
		0x02,
		0x01,
		0x02,
		0x04,
		0x20,
		0x01,
		0x02,
		0x01,
		0x21,
		0x22,
		0x20,
		0x25,
	}
};

const uint16_t tvbgone5Times[] PROGMEM = {
	89, 89,
	178, 89,
	89, 178,
	89, 8952,
	89, 0,
};

const struct IrCode code_tvbgone5 PROGMEM = {
	freq_to_timerval(35807),
	tvbgone5Times,
	{
		0x01,
		0x00,
		0x00,
		0x00,
		0x20,
		0x13,
		0x01,
		0x00,
		0x00,
		0x00,
		0x20,
		0x13,
		0x01,
		0x00,
		0x00,
		0x00,
		0x20,
		0x13,
		0x01,
		0x00,
		0x00,
		0x00,
		0x20,
		0x14,
	}
};

const PGM_P *powerCodes[] PROGMEM  = {
//44 Codes = 34%
//Ajouter Fujitsu rcent, Opera et LG rcent.
//Virer les doublons ?
&code_nonames,
&code_samsung,
&code_samsung2,
&code_philips,
&code_lg,
&code_toshiba2,
&code_toshiba4,
&code_hitachi,
&code_hitashi3,
&code_tvbgone4,
&code_tvbgone5,
&code_fujitsu,
&code_grundig,
&code_sharp,
&code_acer,
&code_sony,
&code_brandt,
&code_panasonic,
&code_thomson,
&code_sanyo,
&code_jvc,
&code_siemens,
&code_pioneer,
&code_mitsubishi,
&code_bluesky,
&code_nec,
&code_jvc2,
&code_viewsonic,
&code_nec2,
&code_advent,
&code_triumph,
&code_acura,
&code_radiola,
&code_magnavox,
&code_goodmans,
&code_aiwa,
&code_daewoo,
&code_firstline,
&code_weird,
&code_phonola,
&code_granada,
&code_asa,
&code_dumont,
&code_novatronic
};

uint8_t num_codes = (sizeof(powerCodes)/sizeof(*powerCodes));
